# BROTgui

A Python GUI for BROT telescopes.

## Installation

Install it with uvx:

    uvx --from git+https://github.com/BROTLib/BROTgui.git brotgui

Run it later as:

    uvx brotgui

## Development

Clone it:

    git clone https://github.com/BROTLib/BROTgui.git
    cd BROTgui

Set up virtual environment:

    uv sync --all-extras

Start GUI with activated venv:

    brotgui

Or via uv:

    uv run brotgui